@@ -566,12 +566,18 @@ class MacalInterpreter:
         value = var.get_value()
         if len(index) == 0:
             return value
+        if value is None:
+            return NIL
         i = 0
         while i < len(index) - 1:
             f = self.evaluate_expression(index[i].expr, scope).value
+            if value is None:
+                return NIL
             value = value[f]
             i += 1
         f = self.evaluate_expression(index[i].expr, scope).value
+        if value is None:
+            return NIL
         value = value[f]
         return value
 
